<?php 

namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\DTO;
use Teknisa\MAN\Services;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;


class ParametrizacoesNoCash extends \Teknisa\MAN\Controllers\TeknisaCrud { 
    protected $servicesParametrizacao;
    protected $fileUploaderService;
    
   public function __construct (Services\ParametrizacoesNoCash $servicesParametrizacao, $parameterBag, Manager $dataSourceManager, Services\FileUploaderService $fileUploaderService) {
       $this->servicesParametrizacao = $servicesParametrizacao;
        $this->parameterBag             = $parameterBag;
        $this->dataSourceManager        = $dataSourceManager;
        $this->fileUploaderService      = $fileUploaderService;
    }
    
    // parametrizações no cash
    ///find
    public function findParametrizacao(DTO\Request $request, DTO\Response $response) {
        if(isset($request->getParameters()['row'])){
            $nrorg =  $request->getParameters()['row'][0]['value'];
        }else{
            $nrorg = NULL;
        }
        $query = $this->servicesParametrizacao->find($nrorg);
        $tratamento = array();

        if($query){
            $urllogo = $query['URLLOGO'];
            unset($query['URLLOGO']);
            
            $color = $query['CORESJSON'];
            unset($query['CORESJSON']);
            
            $idiomaadic = $query['IDIOMAADIC'];
            unset($query['IDIOMAADIC']);
            
            /*
                Transferência dos outros campos da consulta que não são necessários tratamentos
            */
            foreach($query as $field => $value){
                $tratamento[$field] = $query[$field];
            }
            // limpa a query de retorno
            unset($query);
        }else{
            $urllogo = NULL;
            $color = NULL;
            $idiomaadic = NULL;
        }
        
        $this->verifyURLLOGO($urllogo, $tratamento);

        $this->slashColors($color, $tratamento);
        
        $this->slashIDIOMAADIC($idiomaadic, $tratamento);

        $response->addDataSet(new DataSet("paraNoCash_parametrizacoesNoCash", [$tratamento]));
        
        return [$tratamento];
    }
    
    public function slashColors($color, &$tratamento){
        /*
            Tratamento das Cores
                Separação em 3 cores
                Se for null para o front, será exibido uma cor default
        */
        
        if($color){
            $decode = json_decode($color, true);
            
            $tratamento['CORPRIMARIA'] = $decode['CORPRIMARIA'];
            $tratamento['CORPRIMARIASUAVE'] = $decode['CORPRIMARIASUAVE'];
            $tratamento['CORPRIMARIAESCURA'] = $decode['CORPRIMARIAESCURA'];
        }else{
            $tratamento['CORPRIMARIA'] = NULL;
            $tratamento['CORPRIMARIASUAVE'] = NULL;
            $tratamento['CORPRIMARIAESCURA'] = NULL;
        }
    }
    
    public function verifyURLLOGO($urllogo, &$tratamento){
        /*
            Tratamento da URLLOGO
                Se for null para o front, será exibido uma imagem padrão
        */
        if(empty($urllogo)){
            $tratamento['URLLOGO'] = NULL;
        }else{
            $tratamento['URLLOGO'] = $urllogo;
        }
    }
    
    public function slashIDIOMAADIC($idiomaadic, &$tratamento){
        /*
            Tratamento dos idiomas adicionais
                Transformar em array
        */
        if(!empty($idiomaadic)){
            $idiomadiv = explode(";", $idiomaadic);
            $tratamento['IDIOMAADIC'] = $idiomadiv;
        }else{
            $tratamento['IDIOMAADIC'] = NULL;
        }
    }
    
    ///save
    public function saveParametrizacoesNoCash(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();

        // Limpa o número whatsapp
        if(isset($row['NUMEROAJUDA'])){
            $row['NUMEROAJUDA'] = preg_replace("/[^0-9]/", "", $row['NUMEROAJUDA']);
        }else{
            $row['NUMEROAJUDA'] = NULL;
        }

        if(!empty($row['URLLOGO'])){
             $this->handleUrllogoObject($row);
        }
        
        $this->handleCoresJson($row);
        
        $this->handleIdiomaAdic($row);

        $fiels = ['URLAPIPAG', 'PAYMENTCOMPANY', 'MERCHANTKEY', 'MERCHANTID', 'HABCADASTRO', 'MAILFALE', 'RECSENHAMSG', 'IDIOMAPRINC'];
        
        foreach($fiels as $field){
            if(!isset($row[$field])){
                $row[$field] = NULL;
            }
        }
        
        if(!$row['HABCADASTRO']){
            $row['HABCADASTRO'] = 'N'; //DEFAULT VALUE
        }
        
        if(!$row['IDIOMAPRINC']){
            $row['IDIOMAPRINC'] = 'PT'; //DEFAULT VALUE
        }
        
        // Se NRORGINCLUSAO vazio, é o primeiro save
        if(empty($row["NRORGINCLUSAO"])){
            $this->servicesParametrizacao->saveNew($row);
        }else{
            $this->servicesParametrizacao->update($row);
        }

    }
    
    public function saveLogin(&$row){
        $password = md5($row['SENHAOPERFIN']);

        $params = [
            'SENHAOPERFIN'  =>  $password,
            'EMAILOPERFIN'  =>  $row['EMAILOPERFIN'],
            'NRORG'         =>  $row['NRORG']
        ];
        
        $this->servicesParametrizacao->saveLogin($params);
    }
    
    public function handleUrllogoObject(object &$row){
        $urllogo = $row['URLLOGO'];

        if(is_array($urllogo)){
            $this->fileUploaderService->setImageForSave($row, 'URLLOGO', 'URLLOGO');
            $path = $this->servicesParametrizacao->selectFileServerUrl($row['NRORG']);
            $row['URLLOGO'] = $path['FILESERVERURL'] . $row['URLLOGO'];
        }
    }
    
    public function handleCoresJson(object &$row){
        if(!isset($row['CORPRIMARIA'])){
            $row['CORPRIMARIA'] = null;
        }
        
        if(!isset($row['CORPRIMARIASUAVE'])){
            $row['CORPRIMARIASUAVE'] = null;
        }
        
        if(!isset($row['CORPRIMARIAESCURA'])){
            $row['CORPRIMARIAESCURA'] = null;
        }
        
        $CORESJSON = [
            'CORPRIMARIA'       =>  $row['CORPRIMARIA'],
            'CORPRIMARIASUAVE'  =>  $row['CORPRIMARIASUAVE'],
            'CORPRIMARIAESCURA' =>  $row['CORPRIMARIAESCURA']
        ];
        
        unset($row['CORPRIMARIA']);
        unset($row['CORPRIMARIASUAVE']);
        unset($row['CORPRIMARIAESCURA']);
        
        $row['CORESJSON'] = json_encode($CORESJSON);
    }
    
    public function handleIdiomaAdic(object &$row){
        if(isset($row['IDIOMAADIC'])){
            $size = sizeof($row['IDIOMAADIC']);
            if($size == 2){
                $idiomaadic = $row['IDIOMAADIC'][0] .';'. $row['IDIOMAADIC'][1];
            }else if ($size == 1){
                $idiomaadic = $row['IDIOMAADIC'][0];
            }else{
                $idiomaadic = null;
            }
            
            $row['IDIOMAADIC'] = $idiomaadic;
        }else{
            $row['IDIOMAADIC'] = NULL;
        }
    }
    
    public function checkNoCashUser(DTO\Request $request, DTO\Response $response){
        $row = $request->getParameters()['row'];
        
        if($row['CLEAR']){
            $params = [
                'SENHAOPERFIN'  =>  $row['SENHAOPERFIN'],
                'EMAILOPERFIN'  =>  $row['EMAILOPERFIN'],
                'NRORG'         =>  $row['NRORG']
            ];
            $this->servicesParametrizacao->saveLogin($params);
            $response->addDataSet(new DataSet("checkNoCashUser", ['true']));
        }
        else{
            if(isset($row['SENHAOPERFIN'])){
                $password = md5($row['SENHAOPERFIN']);
            }
        
            if(isset($row['EMAILOPERFIN'])){
                $email = $row['EMAILOPERFIN'];
            }
            
            
            $params = [
                'CDSENHAOPERWEB'    =>  $password,
                'DSEMAILOPER'       =>  $email
            ];
            
    
            if($this->servicesParametrizacao->checkNoCashUser($params)){
                
                $result = $this->saveLogin($row);
                $response->addDataSet(new DataSet("checkNoCashUser", ['true']));
            }
            else{
                $response->addDataSet(new DataSet("checkNoCashUser", ['failed']));
            }
            
        }
        
        
        
    }
    
    // parametrizações no cash por filial
    public function findParamsFilial(DTO\Request $request, DTO\Response $response){
        $query = $this->servicesParametrizacao->findParamsFilial();

        foreach ($query as $line => &$row){
            if($row['PAGHABJSON']){
                $enabled = json_decode($row['PAGHABJSON'], true);
                foreach($enabled['ENABLED_PAYMENTS'] as $value){
                    if($value === 'P'){
                        $row['PAGAMENTOPIX'] = true;
                    }else if($value === 'C'){
                        $row['PAGAMENTOCARTAO'] = true;
                    }/*else if($value === 'B'){
                        $row['PAGAMENTOBOLETO'] = true;
                    }*/
                    //PARTE DESATIVADA POIS O PAGAMENTO POR BOLETO AINDA NÃO ESTÁ DISPONÍVEL
                }
            }
        }

        $response->addDataSet(new DataSet("paramsNoCashFilial", $query));
    }
    
    public function deleteParamsFilial(DTO\Request $request, DTO\Response $response){
        $row = $request->getParameters()['row'];
        
        $query = $this->servicesParametrizacao->deleteParamsFilial($row);
    }
    
    public function updateParamsFilial(DTO\Request $request, DTO\Response $response){
        $row = $request->getParameters()['row'];

        $this->handlePayments($row);
        
        $query = $this->servicesParametrizacao->updateParamsFilial($row);
    }
    
    public function insertParamsFilial(DTO\Request $request, DTO\Response $response){
        $row = $request->getParameters()['row'];
        
        if($row["__createdLocal"]){

            $this->handlePayments($row);
            
            $query = $this->servicesParametrizacao->insertParamsFilial($row);
        }else{
            throw new \Exception("Erro ao salvar os dados!");
        }
    }
    
    public function handlePayments(&$row){
        $params = array();
        if(isset($row['PAGAMENTOPIX']) && $row['PAGAMENTOPIX']){
            $params['ENABLED_PAYMENTS'][] = 'P';
        }
        
        if(isset($row['PAGAMENTOCARTAO']) && $row['PAGAMENTOCARTAO']){
            $params['ENABLED_PAYMENTS'][] = 'C';
        }
        
        // DESATIVADO PORQUE A OPÇÃO DE PAGAMENTO POR BOLETA AINDA NÃO ESTÁ DISPONÍVEL
        // if($row['PAGAMENTOBOLETO']){
        //     $params['ENABLED_PAYMENTS'][] = 'B';
        // }
        
        if(!isset($params['ENABLED_PAYMENTS'])){
           $params['ENABLED_PAYMENTS'] = [];
        }
        
        $row['PAGHABJSON'] = json_encode($params);
    }
    
}


?>